/******************************************************************************
*                                                                             *
*                            Module specification                             *
*                                                                             *
*                                Copyright by                                 *
*                                                                             *
*                              Azoteq (Pty) Ltd                               *
*                          Republic of South Africa                           *
*                                                                             *
*                           Tel: +27(0)21 863 0033                            *
*                          E-mail: info@azoteq.com                            *
*                                                                             *
*******************************************************************************
Name             :  main.c
Description      :  Basic functions to setup the IQS259 via I2C (PIC16LF1827 was used)
                    and execute basic instructions
Author           :  Alwino van der Merwe
Date             :  13/06/13
Revision         :  V1.0
*******************************************************************************/



#include "Comms.h"
#include "includes.h"
#include "HW.h"
#include "I2C_HW.h"
#include "i2c_high_level.h"
#include "IQS333.h"
#include "IQS333_handler.h"
#include "pic_handler.h"

#include <pic.h>

// PIC16LF1827 Configuration Bit Settings

__CONFIG(FOSC_INTOSC & WDTE_OFF & PWRTE_ON & MCLRE_OFF & CP_ON & CPD_OFF & BOREN_OFF & CLKOUTEN_OFF & IESO_OFF & FCMEN_OFF);
__CONFIG(WRT_OFF & PLLEN_OFF & STVREN_OFF & BORV_LO & LVP_OFF);

__EEPROM_DATA('H','T','0','2','C','0','3','0');
__EEPROM_DATA('6','V','.','0','8',' ',' ',' ');

#define sleep

/*
********************************************************************************************************************
*				          GLOBAL VARIABLES
********************************************************************************************************************
*/

volatile bit	GODONE		@ ((unsigned)&ADCON0*8)+1;
unsigned int countResetStatus = 0;          // this counter is used to determine whether the IQS was reset

/**
 * This is the main function with the main loop, which will be called continuously
 */
void main(void)
{
    // Do the initial setup of the processor
    Mcu_Initial();

    GIE = 0;
    GIE = 1;
    asm("clrwdt");


    //Comms_init();                          // This initilisation can be done here or in the MCU setup

    // Switch on the IQS333 and debounce
    RA2 = 1;                                // VDDHI ON

    delay_ms(5); // Debounce the VDDHI pin to insure that the IQS333 is switched on properly before Comms start
    
    // initialise the IQS333 with default settings
    IQS333_Button_Wheel_Settings();

    while(1)
    {
           handle_events();     // check whether events occured and which events
    } // End main while loop
}