/******************************************************************************
*                                                                             *
*                            Module specification                             *
*                                                                             *
*                                Copyright by                                 *
*                                                                             *
*                              Azoteq (Pty) Ltd                               *
*                          Republic of South Africa                           *
*                                                                             *
*                           Tel: +27(0)21 863 0033                            *
*                          E-mail: info@azoteq.com                            *
*                                                                             *
*******************************************************************************
Name             :  HW.c
Description      :  PIC specific functions for IQS259 I2C Firmware library
                    and initialisation of devices
Author           :  Alwino van der Merwe
Date             :  13/06/13
Revision         :  V1.0
*******************************************************************************/



////        INCLUDES    /////////
#include <pic.h>			//in Hi-Tech Lite compiler
#include "includes.h"
#include "Comms.h"
#include "HW.h"

/**
 * Define variables
 */

// define the i2c pins for ease of use
#define SDA LATBbits.LATB1                  // Data out
#define SDAP PORTBbits.RB1                  // Data in
#define SCL LATBbits.LATB4                  // i2c Clock


void Time_Process(void)
{
    /**
     * Place user code here
     */
}


/*
	Function name:	ISR
	Parameters:		none
	Return:			none
	Description: 	This is the main interrupt service routine of the MCU

*/
void interrupt ISR(void)
{
    /**
     * Interrupt Service Routine
     * Place code here that needs to be periodically implemented
     */
}


/*
	Function name:	Mcu_Initial
	Parameters:		none
	Return:			none
	Description: 	Responsible for initializing the PIC16LF1827 ports
                        and initial setup of the PIC Processor

*/
void Mcu_Initial(void)
{

    OSCCON = 0b01111011;		
    ANSELA = 0x00;
    ANSELB = 0x00;
    CM1CON0bits.C1ON = 0;
    CM2CON0bits.C2ON = 0;		
    WDTCON = 0x24;

    LATA = 0b00001000;
    TRISA = 0x00;
    LATB = 0x00;
    //TRISB = 0x00;

    TRISB = 0x13;

    TRISA6 = 0;
    TRISBbits.TRISB0 = 1;               //RDY input
    TRISBbits.TRISB1 = 1;		//SDA1 input
    TRISBbits.TRISB4 = 1;		//SCL1 input

    //SCL = 1;
    //SDA = 1;

    //APFCON0 = 0b10001111;
    CCP2SEL = 1;

    //CCP3CON = 0b00001111;   //PWM mode, 
    CCP2CON = 0b00000000;

    //CCPTMRS = 0xEB;		
    CCPTMRS = 0b11100001;			
    PR2 = 250;				
    T2CON = 0x00;			
    CCPR2L = 0;
    DC2B1 = 0;
    DC2B0 = 0;
    TMR2IE = 0;
    TMR2IF = 0;
    TMR2ON = 1;

    CCP3CON = 0b00000000;
    PR6 = 250;
    T6CON = 0x00;
    CCPR3L = 0;
    DC3B1 = 0;
    DC3B0 = 0;
    TMR6IE = 0;
    TMR6IF = 0;
    TMR6ON = 1;

    PR4 = 124;
    TMR4 = 0;
    T4CON = 0x00;
    TMR4IE = 0;
    CCPR1L = 0x00;
    CCP1CON = 0x00;

    OPTION_REG = 0B10000111;		//used to test read times
    TMR0 = 0;
    TMR0IF = 0;
    TMR0IE = 0;

    /* The i2c initialisation can be called by the Comms_init function as well */
    SSP1IF = 0;				//I2C initialized
    SSP1IE = 0;
    SSPSTAT = 0x80;
    SSPCON1 = 0x28;
    SSPADD = 9;                         //100K    19  200K
    SSPCON2 = 0;
    SSPCON3 = 0;
    SSPMSK = 0;

    INTEDG = 1;
    INTE = 0;
    INTF = 0;
    PEIE = 1;

    GIE = 0;
} // End of Mcu_Initial() which initialises the mcu the first time
