/******************************************************************************
*                                                                             	*
*                            Module specification                              	*
*                                                                             	*
*                          IQS333 Setup and Control                             *
*                                                                             	*
*                                Copyright by                                 	*
*                                                                            	*
*                              Azoteq (Pty) Ltd                              	*
*                          Republic of South Africa                           	*
*                                                                             	*
*                           Tel: +27(0)21 863 0033                            	*
*                          E-mail: info@azoteq.com                            	*
*                                                                             	*
*********************************************************************************
Name             :  IQS333_Handler.c
Description      :  This program sets up and interprates the IQS333 device
Author           :  Alwino van der Merwe
Date             :  13/06/13
Revision         :  V1.2
*******************************************************************************/

#include "includes.h"
#include "I2C_HW.h"
#include "IQS333_Handler.h"
#include "i2c_high_level.h"
#include "pic_handler.h"
#include "IQS333.h"
#include <pic.h>
#include "IQS333_init.h"        // values from GUI are loaded from IQS333_init.h (default values already setup)

unsigned char touch0;
unsigned char touch1;
unsigned char prox = 0;


// data buffer for communication with the iqs333
unsigned char data_buffer[30]; //set an arbitrary size, but big enough for IQS333 settings

/**
 * This function sets up the IQS333 for optimum performance in this device -
 * these values can however be overwritten from the GUI
 * In the setup, a start and stop is sent after each register was setup - this is
 * done in order to give the IQS333 time to do conversions while the MCU is setting
 * up the buffer for the next register setup. Thus, it is done to not keep the i2c
 * busy unnecessarily.
 */
void IQS333_Button_Wheel_Settings(void)
{
     lights_on();
	 
    /* Read product number  */
    CommsIQS_start();
    CommsIQS_Read(IQS333_ADDR, VERSION_INFO, &data_buffer[0], 2);
    CommsIQS_stop();

    /* Switch the IQS333 to projection mode */
    data_buffer[0] = SYSTEM_FLAGS_VAL;
    CommsIQS_start();
    CommsIQS_Write(IQS333_ADDR, FLAGS, &data_buffer[0], 1);
    CommsIQS_stop();

    // set active channels on iqs333 CH0 CH1 CH2 CH4 CH5 CH
    /* Set active channels  */
    data_buffer[0] = ACTIVE_CH0;
    data_buffer[1] = ACTIVE_CH1;
    CommsIQS_start();
    CommsIQS_Write(IQS333_ADDR, ACTIVE_CHANNELS, &data_buffer[0], 2);
    CommsIQS_stop();

    /* Setup Touch and Prox thresholds for each channel */
    data_buffer[0] = PROX_THRESHOLD;
    data_buffer[1] = TOUCH_THRESHOLD_CH1;
    data_buffer[2] = TOUCH_THRESHOLD_CH2;
    data_buffer[3] = TOUCH_THRESHOLD_CH3;
    data_buffer[4] = TOUCH_THRESHOLD_CH4;
    data_buffer[5] = TOUCH_THRESHOLD_CH5;
    data_buffer[6] = TOUCH_THRESHOLD_CH6;
    data_buffer[7] = TOUCH_THRESHOLD_CH7;
    data_buffer[8] = TOUCH_THRESHOLD_CH8;
    data_buffer[9] = TOUCH_THRESHOLD_CH9;
    CommsIQS_start();
    CommsIQS_Write(IQS333_ADDR, THRESHOLDS , &data_buffer[0], 10);
    CommsIQS_stop();

    /* Set the  ATI Targets (Target Counts) */
    data_buffer[0] = ATI_TARGET_CH0;
    data_buffer[1] = ATI_TARGET_CH0_9;
    CommsIQS_start();
    CommsIQS_Write(IQS333_ADDR, ATI_TARGETS, &data_buffer[0], 2);
    CommsIQS_stop();

    /* Set the BASE value for each channel */
    data_buffer[0] = MULTIPLIERS_CH0;
    data_buffer[1] = MULTIPLIERS_CH1;
    data_buffer[2] = MULTIPLIERS_CH2;
    data_buffer[3] = MULTIPLIERS_CH3;
    data_buffer[4] = MULTIPLIERS_CH4;
    data_buffer[5] = MULTIPLIERS_CH5;
    data_buffer[6] = MULTIPLIERS_CH6;
    data_buffer[7] = MULTIPLIERS_CH7;
    data_buffer[8] = MULTIPLIERS_CH8;
    data_buffer[9] = MULTIPLIERS_CH9;
    CommsIQS_start();
    CommsIQS_Write(IQS333_ADDR, MULTIPLIERS, &data_buffer[0], 10);
    CommsIQS_stop();

    /* Setup Prox Settings*/
    data_buffer[0] = PROXSETTINGS0_VAL;
    data_buffer[1] = PROXSETTINGS1_VAL;
    data_buffer[2] = PROXSETTINGS2_VAL;
    data_buffer[3] = PROXSETTINGS3_VAL;
    data_buffer[4] = PROXSETTINGS4_VAL;
    data_buffer[5] = PROXSETTINGS5_VAL;
    CommsIQS_start();
    CommsIQS_Write(IQS333_ADDR, PROXSETTINGS, &data_buffer[0], 6);
    CommsIQS_stop();

    /* Setup Compensation (PCC) */
    data_buffer[0] = COMPENSATION_CH0;
    data_buffer[1] = COMPENSATION_CH1;
    data_buffer[2] = COMPENSATION_CH2;
    data_buffer[3] = COMPENSATION_CH3;
    data_buffer[4] = COMPENSATION_CH4;
    data_buffer[5] = COMPENSATION_CH5;
    data_buffer[6] = COMPENSATION_CH6;
    data_buffer[7] = COMPENSATION_CH7;
    data_buffer[8] = COMPENSATION_CH8;
    data_buffer[9] = COMPENSATION_CH9;
    CommsIQS_start();
    CommsIQS_Write(IQS333_ADDR, COMPENSATION, &data_buffer[0], 10);
    CommsIQS_stop();

    /* Set Timings on the IQS333 */
    data_buffer[0] = FILTER_HALT;
    data_buffer[1] = POWER_MODE;
    data_buffer[2] = TIMEOUT_PERIOD;
    data_buffer[3] = CH0_ACF_BETA;
    data_buffer[4] = CH0_9_ACF_BET1;
    CommsIQS_start();
    CommsIQS_Write(IQS333_ADDR, TIMINGS, &data_buffer[0], 5);
    CommsIQS_stop();

    /* Setup PWM  */
    data_buffer[0] = PWM_0;
    data_buffer[1] = PWM_1;
    data_buffer[2] = PWM_2;
    data_buffer[3] = PWM_3;
    //  - Only available on the QFN 32 package
//    data_buffer[4] = PWM_4;
//    data_buffer[5] = PWM_5;
//    data_buffer[6] = PWM_6;
//    data_buffer[7] = PWM_7;
    CommsIQS_start();
    CommsIQS_Write(IQS333_ADDR, PWM, &data_buffer[0], 4);
    CommsIQS_stop();

    /*  Change PWM limits and Speed */
    data_buffer[0] = PWM_LIMITS;
    data_buffer[1] = PWM_SPEED;
    CommsIQS_start();
    CommsIQS_Write(IQS333_ADDR, PWM_LIMIT, &data_buffer[0], 2);
    CommsIQS_stop();

    /* Set Buzzer Output */     //  - Only available on the QFN 32 package
//    data_buffer[0] = BUZZER_VAL;
//    CommsIQS_start();
//    CommsIQS_Write(IQS333_ADDR, BUZZER, &data_buffer[0], 1);
//    CommsIQS_stop();


   /* wait until the ATI algorithm is done */
    do
    {
        delay_ms (10);  // wait for IQS333 to finish conversions, then check ATI bit
        CommsIQS_start();
        CommsIQS_Read(IQS333_ADDR, FLAGS, &data_buffer[0], 1);
        CommsIQS_stop();
    }
    while ((data_buffer[0] & 0b00000100) == 0b00000100);

    // read the error bit to determine if an ATI error occured
    CommsIQS_start();
    CommsIQS_Read(IQS333_ADDR,PROXSETTINGS , &data_buffer[0], 2);
    CommsIQS_stop();

    // if an ATI error occured, switch on buzzer
    if (data_buffer[1] & 0x02 == 0x02)
    {
         buzzer (5);
    }

    lights_off();
}   // End IQS333_Button_Wheel_Settings()

/**
 * This method determines the coordinates of the wheel and handle
 * the events from the buttons and prox
 */
void handle_events(void)
{
    // start communication session
    CommsIQS_start();
    // read status of touch channels
    CommsIQS_Read(IQS333_ADDR, TOUCH_BYTES, &data_buffer[5], 2);
    // end communication session
    CommsIQS_stop();

    touch0 = data_buffer[5];
    touch1 = data_buffer[6];

    /* Proximity status is indicated in touch0 bit 1 */

    /* The touches made was read from the touch registers
     * if there is a touch, do something with the channel
     */
    if(touch0 != 0)
    {
        // Channel 1
	if((touch0 & 0x02) == 0x02)
        {
             RA1 = 1;
             buzzer(2);
        }
	else
        {
            RA1 = 0;
        }
	// Channel 2
	if((touch0 & 0x04) == 0x04)
        {
             RA3 = 1;
             buzzer(2);
        }
	else
        {
             RA3 = 0;
        }
        // Channel 4
	if((touch0 & 0x10) == 0x10)
        {
             RA7 = 1;
             buzzer(2);
        }
	else
        {
             RA7 = 0;
        }
        // Channel 5
	if((touch0 & 0x20) == 0x20)
        {
             RA0 = 1;
             buzzer(2);
        }
	else
        {
             RA0 = 0;
        }
        // Channel 6
	if((touch0 & 0x40) == 0x40)
        {
             RA6 = 1;
             buzzer(2);
        }
	else
        {
             RA6 = 0;
        }
    }
    
}   // End handle_events()

