/******************************************************************************
*                                                                             *
*                            Module specification                             *
*                                                                             *
*                                Copyright by                                 *
*                                                                             *
*                              Azoteq (Pty) Ltd                               *
*                          Republic of South Africa                           *
*                                                                             *
*                           Tel: +27(0)21 863 0033                            *
*                          E-mail: info@azoteq.com                            *
*                                                                             *
*******************************************************************************
Name             :  delay.c
Description      :  i2c high level functions
Author           :  Alwino van der Merwe
Date             :  24/07/13
Revision         :  V1.3.1
*******************************************************************************/


#include "includes.h"
#include "i2c_high_level.h"
#include <pic.h>
#include "Comms.h"
#include "I2C_HW.h"

/*  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
						----    CommsIQS_Read()    ----
	Description:	Reads data from the IQS

	Input:                  read_addr - This is the IQS ADDRESS-COMMAND
				data - Pointer to an array of chars, where the data READ from the IQS is stored
				NoOfBytes - The number of bytes to read from theIQS333

	Limitations:		This function must be preceded by one of the following function calls:
				CommsIQS_start(), CommsIQS_repeat_start(),

				This function must be followed by one of the following function calls:
				CommsIQS_repeat_start(), CommsIQS_stop

*/
void CommsIQS_Read(unsigned char i2c_addr, unsigned char read_addr, unsigned char *data, unsigned char NoOfBytes)
{
	unsigned char i;
// ==================================

	CommsIQS_send((i2c_addr << 1) + 0x00);			// device address + write
	CommsIQS_send(read_addr);				// IQS address-command
	CommsIQS_repeat_start();
	CommsIQS_send((i2c_addr << 1) + 0x01);			// device address + read
	if (NoOfBytes > 1)
	{
		for (i = 0; i < NoOfBytes - 1; i++)
			data[i] = CommsIQS_read_ack();		// all bytes except last must be followed by an ACK
	}
	data[NoOfBytes-1] = CommsIQS_read_nack();		// last byte read must be followed by a NACK
}




/*  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
						---   CommsIQS_Write()   ---
	Description:	Writes data to IQS device

	Input:                  write_addr - This is the IQS ADDRESS-COMMAND
				data - Pointer to an array of chars, which contain the data to write to the IQS
				NoOfBytes - The number of bytes to write to the IQS

	Limitations:		This function must be preceded by one of the following function calls:
				CommsIQS_start(), CommsIQS_repeat_start(),

				This function must be followed by one of the following function calls:
				CommsIQS_repeat_start(), CommsIQS_stop

*/
void CommsIQS_Write(unsigned char i2c_addr, unsigned char write_addr, unsigned char *data, unsigned char NoOfBytes)
{
	unsigned char i;
// ==================================
	CommsIQS_send((i2c_addr << 1) + 0x00);		// device address + write
	CommsIQS_send(write_addr);			// IQS address-command
	for (i = 0 ; i < NoOfBytes ; i++)
		CommsIQS_send(data[i]);
}

