/******************************************************************************
*                                                                             *
*                            Module specification                             *
*                                                                             *
*                                Copyright by                                 *
*                                                                             *
*                              Azoteq (Pty) Ltd                               *
*                          Republic of South Africa                           *
*                                                                             *
*                           Tel: +27(0)21 863 0033                            *
*                          E-mail: info@azoteq.com                            *
*                                                                             *
*******************************************************************************
Name             :  pic_handler.c
Description      :  This class handle the functions that govern the PIC
Author           :  Alwino van der Merwe
Date             :  13/06/13
Revision         :  V1.0
*******************************************************************************/



////        INCLUDES    /////////
#include <pic.h>			//in Hi-Tech Lite compiler
#include "includes.h"
#include "pic_handler.h"

/*
	Function name:	lights_on
	Parameters:		none
	Return:			none
	Description:	Function called if all LEDs on the PIC needs to be switched on
*/
void lights_on(void)
{
    INTE = 0;

    RA0 = 1;
    RA1 = 1;
    RA3 = 1;
    RA6 = 1;
    RA7 = 1;
    delay_ms(20);

}

/*
	Function name:	lights_off
	Parameters:		none
	Return:			none
	Description:	Function called if all LEDs on the PIC needs to be switched off
*/
void lights_off(void)
{
    //all lights OFF
    RA0 = 0;
    RA1 = 0;
    RA3 = 0;
    RA6 = 0;
    RA7 = 0;
} 

/*
	Function name:	delay1ms
	Parameters:		none
	Return:			none
	Description:	Creates a delay of approximately 1 ms on the PIC
*/
void delay1ms(void)
{
    unsigned int i = 0;

    asm("clrwdt");

    for (i = 0; i < 250; i++)  //Tcy = 500n , 1ms/500n / 4ops = 500 loops
    {
        asm("clrwdt");
    }
}

/*
	Function name:	delay_ms
	Parameters:		unsigned int x - the time in ms that needs to be
                                delayed
	Return:			none
	Description:	Creates a delay of approximately x * delay1ms ms, or
                        x ms  on the PIC
*/
void delay_ms(unsigned int x)
{
    unsigned int i;

    for ( i = 0; i < x; i++)
    {
        delay1ms();
    }
}

/*
	Function name:	buzzer
	Parameters:		unsigned char buzzerNum - switches the buzzer on/off buzzerNum times
                                1 = on; 0 = off
	Return:			none
	Description:	Switches the buzzer on/off, creating a clicking noise,
                        mainly for feedback purposes
*/
void buzzer (unsigned char buzzerNum)
{
    TRISBbits.TRISB3 = 0;

    /* Buzz by sending a pulse to the buzzer */
    LATBbits.LATB3 = 1;
    delay_ms(2);
    LATBbits.LATB3 = 0;

    unsigned int i;

    /* This creates a buzzer that buzzes buzzNum timer */
    for(i = 0; i < buzzerNum; i++)
    {
        LATBbits.LATB3 = ~LATBbits.LATB3;
        delay_ms(1);
    }

}

